''' Constants and conversions for import. '''

# Unit conversions
km_to_m = 1000     # Kilometers to meters
nm_to_km = 1.852   # Nautical miles to kilometers
kmh_to_ms = 0.2778 # km/h to m/s
mb_to_pa = 100
kn_to_ms = 0.514444 # Knots to m/s

# Physical constants
rho = 1.15
earth_omega = 7.2921e-5